@@ -15,8 +15,16 @@ if __name__ == '__main__':
     app.mainloop()
       
   else:
-
-    if sys.argv[1] == "getTailExtremityFirstFrame":
+    
+    if sys.argv[1] == "selectZZoutput":
+      
+      print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
+      from zebrazoom.GUIAllPy import SampleApp
+      app = SampleApp()
+      app.askForZZoutputLocation()
+      app.mainloop()
+      
+    elif sys.argv[1] == "getTailExtremityFirstFrame":
       
       pathToVideo = sys.argv[2]
       videoName   = sys.argv[3]
@@ -60,7 +68,7 @@ if __name__ == '__main__':
       import time
       path       = sys.argv[2]
       videoName  = sys.argv[3]
-      configFile = sys.argv[4]      
+      configFile = sys.argv[4]
       codec      = sys.argv[5] if len(sys.argv) >= 6 else 'HFYU'
       lastFrame  = int(sys.argv[6]) if len(sys.argv) >= 7 else -1
       argv2      = sys.argv.copy()
@@ -77,6 +85,15 @@ if __name__ == '__main__':
       mainZZ(path2, videoName, 'avi', configFile, argv2)
     
     
+    elif sys.argv[1] == "DL_createMask":
+      
+      from zebrazoom.code.deepLearningFunctions.labellingFunctions import createMask
+      pathToImgFolder = sys.argv[2]
+      if not(os.path.exists(pathToImgFolder)):
+        pathToImgFolder = os.path.join(os.path.join(os.path.join(dir_path,'ZZoutput'), sys.argv[2]), 'PNGImages')
+      createMask(pathToImgFolder)
+    
+    
     elif sys.argv[1] == "dataPostProcessing":
       
       if sys.argv[2] == "sleepVsMoving":
