@@ -91,7 +91,7 @@ def findRectangularWells(frame, videoPath, hyperparameters, rectangularWellsArea
   for contour in contours:
     print("Possible Well Area:", cv2.contourArea(contour))
     if cv2.contourArea(contour) > minRectangleArea and cv2.contourArea(contour) < maxRectangleArea:
-      if True:
+      if not(hyperparameters["rectangularWellMinMaxXandYmethod"]):
         topLeftCoord          = [0, 0]
         bottomRightCoord      = [0, 0]
         topLeftDistToZero     = float("inf")
@@ -260,6 +260,10 @@ def findWells(videoPath, hyperparameters):
         cvui.imshow(WINDOW_NAME, frame)
         while not(cvui.mouse(cvui.CLICK)):
           cursor = cvui.mouse()
+          frame2 = frame.copy()
+          frame2 = cv2.line(frame2, (cursor.x - 2000, cursor.y), (cursor.x + 2000, cursor.y), (0, 0, 255), 2)
+          frame2 = cv2.line(frame2, (cursor.x, cursor.y - 2000), (cursor.x, cursor.y + 2000), (0, 0, 255), 2)
+          cvui.imshow(WINDOW_NAME, frame2)
           cv2.waitKey(20)
         posCoord[pos] = np.array([cursor.x, cursor.y])
         cv2.destroyWindow(WINDOW_NAME)
