@@ -1,6 +1,7 @@
 import h5py
 import numpy as np
 import cv2
+import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 from zebrazoom.code.popUpAlgoFollow import prepend
 import math
 import os
@@ -10,7 +11,7 @@ from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.headTrac
 from zebrazoom.code.trackingFolder.debugTracking import debugTracking
 from zebrazoom.code.trackingFolder.tailTracking import tailTracking
 from zebrazoom.code.trackingFolder.blackFramesDetection import getThresForBlackFrame, savingBlackFrames
-from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.getTailTipManual import getHeadPositionByFileSaved, findTailTipByUserInput, getTailTipByFileSaved, findHeadPositionByUserInput
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.getTailTipManual import getHeadPositionByFileSaved, findTailTipByUserInput, getTailTipByFileSaved, findHeadPositionByUserInput, getAccentuateFrameForManualPointSelect
 from zebrazoom.code.trackingFolder.eyeTracking.eyeTracking import eyeTracking
 from zebrazoom.code.trackingFolder.postProcessMultipleTrajectories import postProcessMultipleTrajectories
 
@@ -24,8 +25,17 @@ from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTr
 from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTrackingTeresaNicolson import headEmbededTailTrackFindMaxDepthTeresaNicolson, headEmbededTailTrackingTeresaNicolson
 from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.centerOfMassTailTracking import centerOfMassTailTrackFindMaxDepth
 
-def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters, videoName):
+from zebrazoom.code.trackingFolder.trackingFunctions import addBlackLineToImgSetParameters
 
+def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters, videoName, dlModel=0):
+  
+  if hyperparameters["trackingDL"]:
+    import torch
+    from zebrazoom.code.deepLearningFunctions.trackingDL import trackingDL
+    device = torch.device('cuda') if torch.cuda.is_available() else torch.device('cpu')
+    [trackingHeadTailAllAnimals, trackingHeadingAllAnimals, trackingEyesAllAnimals, headPositionFirstFrame, tailTipFirstFrame] = trackingDL(videoPath, wellNumber, wellPositions, hyperparameters, videoName, dlModel, device)
+    return [trackingHeadTailAllAnimals, trackingHeadingAllAnimals, trackingEyesAllAnimals, headPositionFirstFrame, tailTipFirstFrame]
+  
   firstFrame = hyperparameters["firstFrame"]
   if hyperparameters["firstFrameForTracking"] != -1:
     firstFrame = hyperparameters["firstFrameForTracking"]
@@ -40,7 +50,7 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
   headPositionFirstFrame = []
   tailTipFirstFrame = []
   
-  cap = cv2.VideoCapture(videoPath)
+  cap = zzVideoReading.VideoCapture(videoPath)
   if (cap.isOpened()== False): 
     print("Error opening video stream or file")
   frame_width  = int(cap.get(3))
@@ -75,7 +85,11 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
       hyperparameters["headEmbededRemoveBack"] = 1
       hyperparameters["minPixelDiffForBackExtract"] = hyperparameters["headEmbededAutoSet_BackgroundExtractionOption"]
       [frame, thresh1] = headEmbededFrameBackExtract(videoPath, background, hyperparameters, firstFrame)
-      
+    
+    # Setting hyperparameters in order to add line on image
+    if hyperparameters["addBlackLineToImg_Width"]:
+      hyperparameters = addBlackLineToImgSetParameters(hyperparameters, frame)
+    
     # if hyperparameters["invertBlackWhiteOnImages"]:
       # frame   = 255 - frame
     
@@ -88,7 +102,8 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
       headPositionFirstFrame = getHeadPositionByFileSaved(videoPath)
     else:
       if hyperparameters["findHeadPositionByUserInput"]:
-        headPositionFirstFrame = findHeadPositionByUserInput(frame, firstFrame, videoPath)
+        frameForManualPointSelection = getAccentuateFrameForManualPointSelect(frame, hyperparameters)
+        headPositionFirstFrame = findHeadPositionByUserInput(frameForManualPointSelection, firstFrame, videoPath)
       else:
         [frame, gray, thresh1, blur, thresh2, frame2, initialCurFrame, back] = getImages(hyperparameters, cap, videoPath, firstFrame, background, wellNumber, wellPositions)
         cap.set(1, firstFrame)
@@ -96,7 +111,8 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
     if os.path.exists(videoPath+'.csv'):
       tailTipFirstFrame  = getTailTipByFileSaved(hyperparameters,videoPath)
     else:
-      tailTipFirstFrame  = findTailTipByUserInput(frame, firstFrame, videoPath, hyperparameters)
+      frameForManualPointSelection = getAccentuateFrameForManualPointSelect(frame, hyperparameters)
+      tailTipFirstFrame  = findTailTipByUserInput(frameForManualPointSelection, firstFrame, videoPath, hyperparameters)
     if hyperparameters["automaticallySetSomeOfTheHeadEmbededHyperparameters"] == 1:
       hyperparameters = adjustHeadEmbededHyperparameters(hyperparameters, frame, headPositionFirstFrame, tailTipFirstFrame)
     # Getting max depth
@@ -133,7 +149,7 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
     # Tail tracking for frame i
     if hyperparameters["trackTail"] == 1 :
       for animalId in range(0, hyperparameters["nbAnimalsPerWell"]):
-        [trackingHeadTailAllAnimals, trackingHeadingAllAnimals] = tailTracking(animalId, i, firstFrame, videoPath, frame, hyperparameters, thresh1, nbTailPoints, threshForBlackFrames, thetaDiffAccept, trackingHeadTailAllAnimals, trackingHeadingAllAnimals, lastFirstTheta, maxDepth, tailTipFirstFrame, initialCurFrame, back)
+        [trackingHeadTailAllAnimals, trackingHeadingAllAnimals] = tailTracking(animalId, i, firstFrame, videoPath, frame, hyperparameters, thresh1, nbTailPoints, threshForBlackFrames, thetaDiffAccept, trackingHeadTailAllAnimals, trackingHeadingAllAnimals, lastFirstTheta, maxDepth, tailTipFirstFrame, initialCurFrame, back, wellNumber)
     # Eye tracking for frame i
     if hyperparameters["eyeTracking"]:
       trackingEyesAllAnimals = eyeTracking(animalId, i, firstFrame, frame, hyperparameters, thresh1, trackingHeadingAllAnimals, trackingHeadTailAllAnimals, trackingEyesAllAnimals)
