@@ -80,8 +80,8 @@ def applyClustering(clusteringOptions, classifier, outputFolder):
   if os.path.exists(outputFolderResult):
     shutil.rmtree(outputFolderResult)
   os.mkdir(outputFolderResult)
-
-  infile = open(os.path.join(resFolder, nameOfFile),'rb')
+  
+  infile = open(os.path.join(resFolder, nameOfFile + '.pkl'),'rb')
   dfParam = pickle.load(infile)
   infile.close()
 
